@@ -49,7 +49,6 @@
 package com.openexchange.rss;
 
 import java.util.concurrent.atomic.AtomicReference;
-
 import com.openexchange.html.HtmlService;
 import com.openexchange.server.ServiceLookup;
 
@@ -58,6 +57,7 @@ public class RssServices {
     public static final AtomicReference<ServiceLookup> LOOKUP = new AtomicReference<ServiceLookup>();
 
     public static HtmlService getHtmlService() {
-    	return LOOKUP.get().getService(HtmlService.class);
+    	final ServiceLookup services = LOOKUP.get();
+        return null == services ? null : services.getService(HtmlService.class);
     }
 }
